@@ -1,8 +1,8 @@
 """Implements AsteriskInfo Class for gathering stats from the Asterisk Manager 
 Interface (AMI). The AsteriskInfo Class relies on two alternative mechanisms
-for  obtaining the connection parameters for AMI:
-    - Connection parameters be passed to AsteriskInfo on instance instantiation.
-    - AsteriskInfo implements autoconfiguration for the following setups:
+for setting the connection parameters for AMI:
+    - Manually passing connection parameters to AsteriskInfo on instantiation.
+    - Autoconfiguration of AsteriskInfo for the following setups:
         - FreePBX:        The configuration file /etc/amportal.conf is parsed.
         - Plain Asterisk: The configuration file /etc/asterisk/manager.conf 
                           is parsed.
@@ -29,6 +29,7 @@ __status__ = "Development"
 # DEFAULTS
 #
 
+defaultAMIport = 5038
 confFileFreePBX = '/etc/amportal.conf'
 confFileAMI = '/etc/asterisk/manager.conf'
 connTimeout = 5
@@ -41,8 +42,8 @@ class AsteriskInfo:
 
     """
 
-    def __init__(self, host='127.0.0.1', port=5038, user=None, password=None, 
-                 autoInit=True):
+    def __init__(self, host='127.0.0.1', port=defaultAMIport, 
+                 user=None, password=None, autoInit=True):
         """Initialize connection to Asterisk Manager Interface.
         
         @param host:     Asterisk Host
@@ -56,7 +57,7 @@ class AsteriskInfo:
         # Set Connection Parameters
         self._conn = None
         self._amihost = host or '127.0.0.1'
-        self._amiport = port or 5038
+        self._amiport = int(port or defaultAMIport)
         self._amiuser = user
         self._amipass = password
         self._ami_version = None
@@ -148,20 +149,20 @@ class AsteriskInfo:
                 % (self._amihost, self._amiport)
                 )
 
-    def _sendAction(self, action, keys=None, vars=None):
+    def _sendAction(self, action, attrs=None, chan_vars=None):
         """Send action to Asterisk Manager Interface.
         
-        @param action: Action name
-        @param keys:   Tuple of key-value pairs for action attributes.
-        @param vars:   Tuple of key-value pairs for channel variables.
+        @param action:    Action name
+        @param attrs:     Tuple of key-value pairs for action attributes.
+        @param chan_vars: Tuple of key-value pairs for channel variables.
 
         """
         self._conn.write("Action: %s\r\n" % action)
-        if keys:
-            for (key,val) in keys:
+        if attrs:
+            for (key,val) in attrs:
                 self._conn.write("%s: %s\r\n" % (key, val))
-        if vars:
-            for (key,val) in vars:
+        if chan_vars:
+            for (key,val) in chan_vars:
                 self._conn.write("Variable: %s=%s\r\n" % (key, val))
         self._conn.write("\r\n")
 
@@ -638,9 +639,9 @@ class AsteriskInfo:
         """
         re_list = []
         info_dict = {}
-        for filter in trunkList:
-            info_dict[filter[0]] = 0
-            re_list.append(re.compile(filter[1], re.IGNORECASE))
+        for filt in trunkList:
+            info_dict[filt[0]] = 0
+            re_list.append(re.compile(filt[1], re.IGNORECASE))
                   
         if self.checkVersion('1.4'):
             cmd = "core show channels"
